import java.sql.*;
import javax.xml.parsers.*;
import org.w3c.dom.*;
import org.xml.sax.*;

/**
 * Questa classe fornisce un'interfaccia XML ai dati memorizzati su DB.
 *
 * @author Andrea Giovannini
 */
public class Books {
	private String jdbcDriver;
	private String jdbcUrl;
	private String jdbcUser;
	private String jdbcPassword;

	public Books() {
		jdbcDriver = "";
		jdbcUrl = "";
		jdbcUser = "";
		jdbcPassword = "";
	}

	public String getJdbcDriver() {
		return jdbcDriver;
	}

	public void setJdbcDriver(String jdbcDriver) {
		this.jdbcDriver = jdbcDriver;
	}

	public String getJdbcUrl() {
		return jdbcUrl;
	}

	public void setJdbcUrl(String jdbcUrl) {
		this.jdbcUrl = jdbcUrl;
	}

	public String getJdbcUser() {
		return jdbcUser;
	}

	public void setJdbcUser(String jdbcUser) {
		this.jdbcUser = jdbcUser;
	}

	public String getJdbcPassword() {
		return jdbcPassword;
	}

	public void setJdbcPassword(String jdbcPassword) {
		this.jdbcPassword = jdbcPassword;
	}


	/**
	 * Questo metodo restituisce l'elenco di libri presenti su DB come
	 * documento DOM.
	 *
	 * @return Document	l'elenco di libri come documento DOM.
	 */
	public Document query() throws Exception {

		Connection c = null;
		Statement stm = null;
		ResultSet rs = null;
		Document result = null;

		try {
			// carica il driver JDBC
			Class.forName(jdbcDriver).newInstance();
		} catch (Exception e) {
			System.err.println("Unable to load driver");
			return null;
		}

		try {
      		// crea il parser XML
			DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = dbf.newDocumentBuilder();
			result = builder.newDocument();
			Element books = result.createElement("BOOKS");

			c = DriverManager.getConnection(jdbcUrl, jdbcUser, jdbcPassword);
			stm = c.createStatement();
			rs = stm.executeQuery("SELECT code, author, title FROM books");

			while (rs.next()) {
				// per ogni record crea un corrispondente elemento DOM
				Element book = result.createElement("BOOK"),
					code = result.createElement("CODE"),
					author = result.createElement("AUTHOR"),
					title = result.createElement("TITLE");


				code.appendChild(result.createTextNode(rs.getString("code")));
				author.appendChild(result.createTextNode(rs.getString("author")));
				title.appendChild(result.createTextNode(rs.getString("title")));

				book.appendChild(code);
				book.appendChild(author);
				book.appendChild(title);

				books.appendChild(book);
			}

			result.appendChild(books);
		} catch (Exception e) {
			e.printStackTrace();
			System.err.println("Exception reading and formatting data");
			throw e;
		} finally {
			try {
				// clean up everything
				if (rs != null) { rs.close(); }
				if (stm != null) { stm.close(); }
				if (c != null) { c.close(); }
			} catch (SQLException sqle) {}
		}
		return result;
	}

}
