
import javax.xml.parsers.*;
import org.w3c.dom.*;

/**
 * Classe LogonForm.
 * Questo bean  associato alla form di logon ed incapsula il processo
 * di autenticazione dell'utente.
 *
 * @author Andrea Giovannini
 */
public class LogonForm {
	// user name
	private String	usrName;

	// password
	private String	password;

	// flag che indica se il logon non  
	// stato eseguito correttamente
	private boolean	logonFailed;

	public LogonForm() {
		usrName = "";
		password = "";
		logonFailed= false;
	}
	
	public String getUsrName() {
		return usrName;
	}
	
	public void setUsrName(String usrName) {
		this.usrName = usrName;
	}

	public String getPassword() {
		return password;
	}
	
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Questo metodo controlla se le informazioni inserite sono corrette.
	 * Per semplicit user name e password sono cablate nel codice; tutti i
	 * dettagli di una reale implementazione sarebbero comunque incapsulati
	 * in questo metodo.
	 *
	 * @return boolean	true se l'utente  autorizzato, false altrimenti.
	 */
	public boolean process() {
		if ((usrName.trim().equals("moka")) && (password.trim().equals("moka"))) {
			return true;
		} else {
			logonFailed = true;
			return false;
		}
	}

	/**
	 * Questo metodo genera un documento DOM corrispondente al bean.
	 *
	 * @return Document		il documento DOM corrispondente a questo bean.
	 */
	public Document toXML() {
		try {
			DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = dbf.newDocumentBuilder();
			Document doc = builder.newDocument();
			
			Element root = doc.createElement("LOGON_FORM"),
					usrNameEl = doc.createElement("USR_NAME"),
					passwordEl = doc.createElement("PASSWORD");
					
			usrNameEl.appendChild(doc.createTextNode(usrName));
			passwordEl.appendChild(doc.createTextNode(password));
			
			root.appendChild(usrNameEl);
			root.appendChild(passwordEl);

			if (logonFailed) {
				Element errorEl = doc.createElement("ERROR");
				errorEl.appendChild(doc.createTextNode("Logon failed"));
				root.appendChild(errorEl);
			}
			
			doc.appendChild(root);
			
			return doc;
		} catch (Exception e) {
			return null;
		}
	}
}
